NUCAPS Reader
=============

.. automodule:: polar2grid.readers.nucaps
    :noindex:

Command Line Arguments
----------------------

.. argparse::
    :module: polar2grid.readers.nucaps
    :func: add_reader_argument_groups
    :prog: polar2grid.sh -r nucaps -w <writer>
    :passparser:
